.. _api-batch-processes-label:

Implemented Batch Processes
===========================

LSF
---

.. automodule:: b2luigi.batch.processes.lsf
   :members:
   :private-members:
   :show-inheritance:

HTCondor
--------

.. automodule:: b2luigi.batch.processes.htcondor
   :members:
   :private-members:
   :show-inheritance:

Slurm
-----

.. automodule:: b2luigi.batch.processes.slurm
   :members:
   :private-members:
   :show-inheritance:

``gbasf2``
----------

.. automodule:: b2luigi.batch.processes.gbasf2
   :members:
   :private-members:
   :show-inheritance:
